==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETUnconditionalWhileNode.h <==
// public class soot.dava.internal.SET.SETUnconditionalWhileNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 92d03241e310e374 soot_dava_internal_SET_SETCycleNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class 97c8442b03ba5c5f soot_dava_internal_SET_SETUnconditionalWhileNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETCycleNode

#include "soot/dava/internal/SET/SETCycleNode.h"

#ifndef _JC_soot_dava_internal_SET_SETUnconditionalWhileNode_H_
#define _JC_soot_dava_internal_SET_SETUnconditionalWhileNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$_init$ffc747eec5c1567b(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *, struct _jc_soot_util_IterableSet$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *);
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method_info$get__5fNaturalExits$93615053d2db173e;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *);
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETCycleNode$vmethods	soot_dava_internal_SET_SETCycleNode;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods	soot_dava_internal_SET_SETUnconditionalWhileNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs {
    _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs	soot_dava_internal_SET_SETUnconditionalWhileNode;
    _jc_soot_dava_internal_SET_SETCycleNode$sub_refs	soot_dava_internal_SET_SETCycleNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs	soot_dava_internal_SET_SETCycleNode;
    _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs	soot_dava_internal_SET_SETUnconditionalWhileNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object {
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETUnconditionalWhileNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETUnconditionalWhileNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETUnconditionalWhileNode.h <==
// public class soot.dava.internal.SET.SETUnconditionalWhileNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 92d03241e310e374 soot_dava_internal_SET_SETCycleNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class 97c8442b03ba5c5f soot_dava_internal_SET_SETUnconditionalWhileNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETCycleNode

#include "soot/dava/internal/SET/SETCycleNode.h"

#ifndef _JC_soot_dava_internal_SET_SETUnconditionalWhileNode_H_
#define _JC_soot_dava_internal_SET_SETUnconditionalWhileNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$_init$ffc747eec5c1567b(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$method_info$get__5fNaturalExits$93615053d2db173e;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETCycleNode$vmethods	soot_dava_internal_SET_SETCycleNode;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vmethods	soot_dava_internal_SET_SETUnconditionalWhileNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs {
    _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_refs	soot_dava_internal_SET_SETUnconditionalWhileNode;
    _jc_soot_dava_internal_SET_SETCycleNode$sub_refs	soot_dava_internal_SET_SETCycleNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETCycleNode$sub_nonrefs	soot_dava_internal_SET_SETCycleNode;
    _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$sub_nonrefs	soot_dava_internal_SET_SETUnconditionalWhileNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$object {
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETUnconditionalWhileNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$vtype _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETUnconditionalWhileNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETUnconditionalWhileNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETUnconditionalWhileNode_H_ */
